@@ -16,6 +16,7 @@ in_D <- sample(c(0, 1), size = 100, replace = TRUE, prob = c(1, 0))
 
 testthat::test_that("get_valid_sources returns correct results", {
 
+    testthat::skip_on_cran()
 
     stratum_1 <- tibble::tibble(in_A, in_B, in_C, in_D)
     testthat::expect_true(setequal(get_valid_sources(stratum_1),
@@ -32,6 +33,8 @@ testthat::test_that("get_valid_sources returns correct results", {
 testthat::test_that("internal run_lcmcr function returns correct results for
                     estimable and non-estimable strata", {
 
+                        testthat::skip_on_cran()
+
                         stratum_1 <- tibble::tibble(in_A, in_B, in_C, in_D) %>%
                             dplyr::mutate(rs = rowSums(.)) %>%
                             dplyr::filter(rs >= 1) %>%
@@ -65,6 +68,8 @@ testthat::test_that("internal run_lcmcr function returns correct results for
 
 testthat::test_that("mse function returns correct results for estimable and non-estimable strata", {
 
+    testthat::skip_on_cran()
+
     stratum_1 <- tibble::tibble(in_A, in_B, in_C, in_D)
     r1 <- mse(stratum_data = stratum_1,
               stratum_name = "stratum 1",
@@ -96,6 +101,8 @@ testthat::test_that("mse function returns correct results for estimable and non-
 
 testthat::test_that("mse function returns correct results when using lookup functionality", {
 
+    testthat::skip_on_cran()
+
     local_dir <- system.file("extdata", "right", package = "verdata")
     replicates <- read_replicates(local_dir, "reclutamiento", replicate_nums = 1,
                                   version = "v1", crash = 1)
@@ -111,16 +118,13 @@ testthat::test_that("mse function returns correct results when using lookup func
 
     # there are warnings here because our toy estimates directory does not contain
     # the same number of files as the real estimates directory would
-    s3_start <- Sys.time()
     r3 <- mse(stratum_data = stratum_3,
               stratum_name = "stratum 3",
               estimates_dir = estimates_dir)
-    s3_end <- Sys.time()
 
     testthat::expect_equal(nrow(r3), 1000)
     testthat::expect_named(r3, c("validated", "N", "valid_sources", "n_obs", "stratum_name"))
     testthat::expect_equal(round(mean(r3$N), 0), 2066)
-    testthat::expect_true(as.numeric(s3_end - s3_start) < 2) # just looking up, should be fast
 
     # not pre-calculated
     stratum_4 <- replicates %>%
@@ -143,6 +147,8 @@ testthat::test_that("mse function returns correct results when using lookup func
 
 testthat::test_that("mse function returns errors when inputs are misspecified", {
 
+    testthat::skip_on_cran()
+
     local_dir <- system.file("extdata", "right", package = "verdata")
     replicates <- read_replicates(local_dir, "reclutamiento", replicate_nums = 1,
                                   version = "v1", crash = 1)
@@ -167,6 +173,7 @@ testthat::test_that("mse function returns errors when inputs are misspecified",
 
 testthat::test_that("lookup function correctly finds strata that have and have not been estimated", {
 
+    testthat::skip_on_cran()
 
     local_dir <- system.file("extdata", "right", package = "verdata")
     replicates <- read_replicates(local_dir, "reclutamiento", replicate_nums = 1,
